@@ -1,14 +1,14 @@
 """
 Type annotations for ssm service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_ssm.literals import AssociationComplianceSeverity
+    from mypy_boto3_ssm.literals import AssociationComplianceSeverityType
 
-    data: AssociationComplianceSeverity = "CRITICAL"
+    data: AssociationComplianceSeverityType = "CRITICAL"
     ```
 """
 import sys
@@ -20,31 +20,31 @@ else:
 
 
 __all__ = (
-    "AssociationComplianceSeverity",
-    "AssociationExecutionFilterKey",
-    "AssociationExecutionTargetsFilterKey",
-    "AssociationFilterKey",
-    "AssociationFilterOperatorType",
-    "AssociationStatusName",
-    "AssociationSyncCompliance",
-    "AttachmentHashType",
-    "AttachmentsSourceKey",
-    "AutomationExecutionFilterKey",
-    "AutomationExecutionStatus",
-    "AutomationSubtype",
-    "AutomationType",
-    "CalendarState",
+    "AssociationComplianceSeverityType",
+    "AssociationExecutionFilterKeyType",
+    "AssociationExecutionTargetsFilterKeyType",
+    "AssociationFilterKeyType",
+    "AssociationFilterOperatorTypeType",
+    "AssociationStatusNameType",
+    "AssociationSyncComplianceType",
+    "AttachmentHashTypeType",
+    "AttachmentsSourceKeyType",
+    "AutomationExecutionFilterKeyType",
+    "AutomationExecutionStatusType",
+    "AutomationSubtypeType",
+    "AutomationTypeType",
+    "CalendarStateType",
     "CommandExecutedWaiterName",
-    "CommandFilterKey",
-    "CommandInvocationStatus",
-    "CommandPluginStatus",
-    "CommandStatus",
-    "ComplianceQueryOperatorType",
-    "ComplianceSeverity",
-    "ComplianceStatus",
-    "ComplianceUploadType",
-    "ConnectionStatus",
-    "DescribeActivationsFilterKeys",
+    "CommandFilterKeyType",
+    "CommandInvocationStatusType",
+    "CommandPluginStatusType",
+    "CommandStatusType",
+    "ComplianceQueryOperatorTypeType",
+    "ComplianceSeverityType",
+    "ComplianceStatusType",
+    "ComplianceUploadTypeType",
+    "ConnectionStatusType",
+    "DescribeActivationsFilterKeysType",
     "DescribeActivationsPaginatorName",
     "DescribeAssociationExecutionTargetsPaginatorName",
     "DescribeAssociationExecutionsPaginatorName",
@@ -73,30 +73,30 @@ __all__ = (
     "DescribePatchGroupsPaginatorName",
     "DescribePatchPropertiesPaginatorName",
     "DescribeSessionsPaginatorName",
-    "DocumentFilterKey",
-    "DocumentFormat",
-    "DocumentHashType",
-    "DocumentMetadataEnum",
-    "DocumentParameterType",
-    "DocumentPermissionType",
-    "DocumentReviewAction",
-    "DocumentReviewCommentType",
-    "DocumentStatus",
-    "DocumentType",
-    "ExecutionMode",
-    "Fault",
+    "DocumentFilterKeyType",
+    "DocumentFormatType",
+    "DocumentHashTypeType",
+    "DocumentMetadataEnumType",
+    "DocumentParameterTypeType",
+    "DocumentPermissionTypeType",
+    "DocumentReviewActionType",
+    "DocumentReviewCommentTypeType",
+    "DocumentStatusType",
+    "DocumentTypeType",
+    "ExecutionModeType",
+    "FaultType",
     "GetInventoryPaginatorName",
     "GetInventorySchemaPaginatorName",
     "GetOpsSummaryPaginatorName",
     "GetParameterHistoryPaginatorName",
     "GetParametersByPathPaginatorName",
-    "InstanceInformationFilterKey",
-    "InstancePatchStateOperatorType",
-    "InventoryAttributeDataType",
-    "InventoryDeletionStatus",
-    "InventoryQueryOperatorType",
-    "InventorySchemaDeleteOption",
-    "LastResourceDataSyncStatus",
+    "InstanceInformationFilterKeyType",
+    "InstancePatchStateOperatorTypeType",
+    "InventoryAttributeDataTypeType",
+    "InventoryDeletionStatusType",
+    "InventoryQueryOperatorTypeType",
+    "InventorySchemaDeleteOptionType",
+    "LastResourceDataSyncStatusType",
     "ListAssociationVersionsPaginatorName",
     "ListAssociationsPaginatorName",
     "ListCommandInvocationsPaginatorName",
@@ -110,52 +110,52 @@ __all__ = (
     "ListOpsMetadataPaginatorName",
     "ListResourceComplianceSummariesPaginatorName",
     "ListResourceDataSyncPaginatorName",
-    "MaintenanceWindowExecutionStatus",
-    "MaintenanceWindowResourceType",
-    "MaintenanceWindowTaskType",
-    "NotificationEvent",
-    "NotificationType",
-    "OperatingSystem",
-    "OpsFilterOperatorType",
-    "OpsItemDataType",
-    "OpsItemEventFilterKey",
-    "OpsItemEventFilterOperator",
-    "OpsItemFilterKey",
-    "OpsItemFilterOperator",
-    "OpsItemRelatedItemsFilterKey",
-    "OpsItemRelatedItemsFilterOperator",
-    "OpsItemStatus",
-    "ParameterTier",
-    "ParameterType",
-    "ParametersFilterKey",
-    "PatchAction",
-    "PatchComplianceDataState",
-    "PatchComplianceLevel",
-    "PatchDeploymentStatus",
-    "PatchFilterKey",
-    "PatchOperationType",
-    "PatchProperty",
-    "PatchSet",
-    "PingStatus",
-    "PlatformType",
-    "RebootOption",
-    "ResourceDataSyncS3Format",
-    "ResourceType",
-    "ResourceTypeForTagging",
-    "ReviewStatus",
-    "SessionFilterKey",
-    "SessionState",
-    "SessionStatus",
-    "SignalType",
-    "StepExecutionFilterKey",
-    "StopType",
+    "MaintenanceWindowExecutionStatusType",
+    "MaintenanceWindowResourceTypeType",
+    "MaintenanceWindowTaskTypeType",
+    "NotificationEventType",
+    "NotificationTypeType",
+    "OperatingSystemType",
+    "OpsFilterOperatorTypeType",
+    "OpsItemDataTypeType",
+    "OpsItemEventFilterKeyType",
+    "OpsItemEventFilterOperatorType",
+    "OpsItemFilterKeyType",
+    "OpsItemFilterOperatorType",
+    "OpsItemRelatedItemsFilterKeyType",
+    "OpsItemRelatedItemsFilterOperatorType",
+    "OpsItemStatusType",
+    "ParameterTierType",
+    "ParameterTypeType",
+    "ParametersFilterKeyType",
+    "PatchActionType",
+    "PatchComplianceDataStateType",
+    "PatchComplianceLevelType",
+    "PatchDeploymentStatusType",
+    "PatchFilterKeyType",
+    "PatchOperationTypeType",
+    "PatchPropertyType",
+    "PatchSetType",
+    "PingStatusType",
+    "PlatformTypeType",
+    "RebootOptionType",
+    "ResourceDataSyncS3FormatType",
+    "ResourceTypeForTaggingType",
+    "ResourceTypeType",
+    "ReviewStatusType",
+    "SessionFilterKeyType",
+    "SessionStateType",
+    "SessionStatusType",
+    "SignalTypeType",
+    "StepExecutionFilterKeyType",
+    "StopTypeType",
 )
 
 
-AssociationComplianceSeverity = Literal["CRITICAL", "HIGH", "LOW", "MEDIUM", "UNSPECIFIED"]
-AssociationExecutionFilterKey = Literal["CreatedTime", "ExecutionId", "Status"]
-AssociationExecutionTargetsFilterKey = Literal["ResourceId", "ResourceType", "Status"]
-AssociationFilterKey = Literal[
+AssociationComplianceSeverityType = Literal["CRITICAL", "HIGH", "LOW", "MEDIUM", "UNSPECIFIED"]
+AssociationExecutionFilterKeyType = Literal["CreatedTime", "ExecutionId", "Status"]
+AssociationExecutionTargetsFilterKeyType = Literal["ResourceId", "ResourceType", "Status"]
+AssociationFilterKeyType = Literal[
     "AssociationId",
     "AssociationName",
     "AssociationStatusName",
@@ -165,12 +165,12 @@ AssociationFilterKey = Literal[
     "Name",
     "ResourceGroupName",
 ]
-AssociationFilterOperatorType = Literal["EQUAL", "GREATER_THAN", "LESS_THAN"]
-AssociationStatusName = Literal["Failed", "Pending", "Success"]
-AssociationSyncCompliance = Literal["AUTO", "MANUAL"]
-AttachmentHashType = Literal["Sha256"]
-AttachmentsSourceKey = Literal["AttachmentReference", "S3FileUrl", "SourceUrl"]
-AutomationExecutionFilterKey = Literal[
+AssociationFilterOperatorTypeType = Literal["EQUAL", "GREATER_THAN", "LESS_THAN"]
+AssociationStatusNameType = Literal["Failed", "Pending", "Success"]
+AssociationSyncComplianceType = Literal["AUTO", "MANUAL"]
+AttachmentHashTypeType = Literal["Sha256"]
+AttachmentsSourceKeyType = Literal["AttachmentReference", "S3FileUrl", "SourceUrl"]
+AutomationExecutionFilterKeyType = Literal[
     "AutomationSubtype",
     "AutomationType",
     "CurrentAction",
@@ -184,7 +184,7 @@ AutomationExecutionFilterKey = Literal[
     "TagKey",
     "TargetResourceGroup",
 ]
-AutomationExecutionStatus = Literal[
+AutomationExecutionStatusType = Literal[
     "Approved",
     "Cancelled",
     "Cancelling",
@@ -204,28 +204,32 @@ AutomationExecutionStatus = Literal[
     "TimedOut",
     "Waiting",
 ]
-AutomationSubtype = Literal["ChangeRequest"]
-AutomationType = Literal["CrossAccount", "Local"]
-CalendarState = Literal["CLOSED", "OPEN"]
+AutomationSubtypeType = Literal["ChangeRequest"]
+AutomationTypeType = Literal["CrossAccount", "Local"]
+CalendarStateType = Literal["CLOSED", "OPEN"]
 CommandExecutedWaiterName = Literal["command_executed"]
-CommandFilterKey = Literal[
+CommandFilterKeyType = Literal[
     "DocumentName", "ExecutionStage", "InvokedAfter", "InvokedBefore", "Status"
 ]
-CommandInvocationStatus = Literal[
+CommandInvocationStatusType = Literal[
     "Cancelled", "Cancelling", "Delayed", "Failed", "InProgress", "Pending", "Success", "TimedOut"
 ]
-CommandPluginStatus = Literal["Cancelled", "Failed", "InProgress", "Pending", "Success", "TimedOut"]
-CommandStatus = Literal[
+CommandPluginStatusType = Literal[
+    "Cancelled", "Failed", "InProgress", "Pending", "Success", "TimedOut"
+]
+CommandStatusType = Literal[
     "Cancelled", "Cancelling", "Failed", "InProgress", "Pending", "Success", "TimedOut"
 ]
-ComplianceQueryOperatorType = Literal[
+ComplianceQueryOperatorTypeType = Literal[
     "BEGIN_WITH", "EQUAL", "GREATER_THAN", "LESS_THAN", "NOT_EQUAL"
 ]
-ComplianceSeverity = Literal["CRITICAL", "HIGH", "INFORMATIONAL", "LOW", "MEDIUM", "UNSPECIFIED"]
-ComplianceStatus = Literal["COMPLIANT", "NON_COMPLIANT"]
-ComplianceUploadType = Literal["COMPLETE", "PARTIAL"]
-ConnectionStatus = Literal["Connected", "NotConnected"]
-DescribeActivationsFilterKeys = Literal["ActivationIds", "DefaultInstanceName", "IamRole"]
+ComplianceSeverityType = Literal[
+    "CRITICAL", "HIGH", "INFORMATIONAL", "LOW", "MEDIUM", "UNSPECIFIED"
+]
+ComplianceStatusType = Literal["COMPLIANT", "NON_COMPLIANT"]
+ComplianceUploadTypeType = Literal["COMPLETE", "PARTIAL"]
+ConnectionStatusType = Literal["Connected", "NotConnected"]
+DescribeActivationsFilterKeysType = Literal["ActivationIds", "DefaultInstanceName", "IamRole"]
 DescribeActivationsPaginatorName = Literal["describe_activations"]
 DescribeAssociationExecutionTargetsPaginatorName = Literal["describe_association_execution_targets"]
 DescribeAssociationExecutionsPaginatorName = Literal["describe_association_executions"]
@@ -266,16 +270,16 @@ DescribePatchBaselinesPaginatorName = Literal["describe_patch_baselines"]
 DescribePatchGroupsPaginatorName = Literal["describe_patch_groups"]
 DescribePatchPropertiesPaginatorName = Literal["describe_patch_properties"]
 DescribeSessionsPaginatorName = Literal["describe_sessions"]
-DocumentFilterKey = Literal["DocumentType", "Name", "Owner", "PlatformTypes"]
-DocumentFormat = Literal["JSON", "TEXT", "YAML"]
-DocumentHashType = Literal["Sha1", "Sha256"]
-DocumentMetadataEnum = Literal["DocumentReviews"]
-DocumentParameterType = Literal["String", "StringList"]
-DocumentPermissionType = Literal["Share"]
-DocumentReviewAction = Literal["Approve", "Reject", "SendForReview", "UpdateReview"]
-DocumentReviewCommentType = Literal["Comment"]
-DocumentStatus = Literal["Active", "Creating", "Deleting", "Failed", "Updating"]
-DocumentType = Literal[
+DocumentFilterKeyType = Literal["DocumentType", "Name", "Owner", "PlatformTypes"]
+DocumentFormatType = Literal["JSON", "TEXT", "YAML"]
+DocumentHashTypeType = Literal["Sha1", "Sha256"]
+DocumentMetadataEnumType = Literal["DocumentReviews"]
+DocumentParameterTypeType = Literal["String", "StringList"]
+DocumentPermissionTypeType = Literal["Share"]
+DocumentReviewActionType = Literal["Approve", "Reject", "SendForReview", "UpdateReview"]
+DocumentReviewCommentTypeType = Literal["Comment"]
+DocumentStatusType = Literal["Active", "Creating", "Deleting", "Failed", "Updating"]
+DocumentTypeType = Literal[
     "ApplicationConfiguration",
     "ApplicationConfigurationSchema",
     "Automation",
@@ -289,14 +293,14 @@ DocumentType = Literal[
     "ProblemAnalysisTemplate",
     "Session",
 ]
-ExecutionMode = Literal["Auto", "Interactive"]
-Fault = Literal["Client", "Server", "Unknown"]
+ExecutionModeType = Literal["Auto", "Interactive"]
+FaultType = Literal["Client", "Server", "Unknown"]
 GetInventoryPaginatorName = Literal["get_inventory"]
 GetInventorySchemaPaginatorName = Literal["get_inventory_schema"]
 GetOpsSummaryPaginatorName = Literal["get_ops_summary"]
 GetParameterHistoryPaginatorName = Literal["get_parameter_history"]
 GetParametersByPathPaginatorName = Literal["get_parameters_by_path"]
-InstanceInformationFilterKey = Literal[
+InstanceInformationFilterKeyType = Literal[
     "ActivationIds",
     "AgentVersion",
     "AssociationStatus",
@@ -306,14 +310,14 @@ InstanceInformationFilterKey = Literal[
     "PlatformTypes",
     "ResourceType",
 ]
-InstancePatchStateOperatorType = Literal["Equal", "GreaterThan", "LessThan", "NotEqual"]
-InventoryAttributeDataType = Literal["number", "string"]
-InventoryDeletionStatus = Literal["Complete", "InProgress"]
-InventoryQueryOperatorType = Literal[
+InstancePatchStateOperatorTypeType = Literal["Equal", "GreaterThan", "LessThan", "NotEqual"]
+InventoryAttributeDataTypeType = Literal["number", "string"]
+InventoryDeletionStatusType = Literal["Complete", "InProgress"]
+InventoryQueryOperatorTypeType = Literal[
     "BeginWith", "Equal", "Exists", "GreaterThan", "LessThan", "NotEqual"
 ]
-InventorySchemaDeleteOption = Literal["DeleteSchema", "DisableSchema"]
-LastResourceDataSyncStatus = Literal["Failed", "InProgress", "Successful"]
+InventorySchemaDeleteOptionType = Literal["DeleteSchema", "DisableSchema"]
+LastResourceDataSyncStatusType = Literal["Failed", "InProgress", "Successful"]
 ListAssociationVersionsPaginatorName = Literal["list_association_versions"]
 ListAssociationsPaginatorName = Literal["list_associations"]
 ListCommandInvocationsPaginatorName = Literal["list_command_invocations"]
@@ -327,7 +331,7 @@ ListOpsItemRelatedItemsPaginatorName = Literal["list_ops_item_related_items"]
 ListOpsMetadataPaginatorName = Literal["list_ops_metadata"]
 ListResourceComplianceSummariesPaginatorName = Literal["list_resource_compliance_summaries"]
 ListResourceDataSyncPaginatorName = Literal["list_resource_data_sync"]
-MaintenanceWindowExecutionStatus = Literal[
+MaintenanceWindowExecutionStatusType = Literal[
     "CANCELLED",
     "CANCELLING",
     "FAILED",
@@ -337,11 +341,11 @@ MaintenanceWindowExecutionStatus = Literal[
     "SUCCESS",
     "TIMED_OUT",
 ]
-MaintenanceWindowResourceType = Literal["INSTANCE", "RESOURCE_GROUP"]
-MaintenanceWindowTaskType = Literal["AUTOMATION", "LAMBDA", "RUN_COMMAND", "STEP_FUNCTIONS"]
-NotificationEvent = Literal["All", "Cancelled", "Failed", "InProgress", "Success", "TimedOut"]
-NotificationType = Literal["Command", "Invocation"]
-OperatingSystem = Literal[
+MaintenanceWindowResourceTypeType = Literal["INSTANCE", "RESOURCE_GROUP"]
+MaintenanceWindowTaskTypeType = Literal["AUTOMATION", "LAMBDA", "RUN_COMMAND", "STEP_FUNCTIONS"]
+NotificationEventType = Literal["All", "Cancelled", "Failed", "InProgress", "Success", "TimedOut"]
+NotificationTypeType = Literal["Command", "Invocation"]
+OperatingSystemType = Literal[
     "AMAZON_LINUX",
     "AMAZON_LINUX_2",
     "CENTOS",
@@ -353,13 +357,13 @@ OperatingSystem = Literal[
     "UBUNTU",
     "WINDOWS",
 ]
-OpsFilterOperatorType = Literal[
+OpsFilterOperatorTypeType = Literal[
     "BeginWith", "Equal", "Exists", "GreaterThan", "LessThan", "NotEqual"
 ]
-OpsItemDataType = Literal["SearchableString", "String"]
-OpsItemEventFilterKey = Literal["OpsItemId"]
-OpsItemEventFilterOperator = Literal["Equal"]
-OpsItemFilterKey = Literal[
+OpsItemDataTypeType = Literal["SearchableString", "String"]
+OpsItemEventFilterKeyType = Literal["OpsItemId"]
+OpsItemEventFilterOperatorType = Literal["Equal"]
+OpsItemFilterKeyType = Literal[
     "ActualEndTime",
     "ActualStartTime",
     "AutomationId",
@@ -387,10 +391,10 @@ OpsItemFilterKey = Literal[
     "Status",
     "Title",
 ]
-OpsItemFilterOperator = Literal["Contains", "Equal", "GreaterThan", "LessThan"]
-OpsItemRelatedItemsFilterKey = Literal["AssociationId", "ResourceType", "ResourceUri"]
-OpsItemRelatedItemsFilterOperator = Literal["Equal"]
-OpsItemStatus = Literal[
+OpsItemFilterOperatorType = Literal["Contains", "Equal", "GreaterThan", "LessThan"]
+OpsItemRelatedItemsFilterKeyType = Literal["AssociationId", "ResourceType", "ResourceUri"]
+OpsItemRelatedItemsFilterOperatorType = Literal["Equal"]
+OpsItemStatusType = Literal[
     "Approved",
     "Cancelled",
     "Cancelling",
@@ -410,11 +414,11 @@ OpsItemStatus = Literal[
     "Scheduled",
     "TimedOut",
 ]
-ParameterTier = Literal["Advanced", "Intelligent-Tiering", "Standard"]
-ParameterType = Literal["SecureString", "String", "StringList"]
-ParametersFilterKey = Literal["KeyId", "Name", "Type"]
-PatchAction = Literal["ALLOW_AS_DEPENDENCY", "BLOCK"]
-PatchComplianceDataState = Literal[
+ParameterTierType = Literal["Advanced", "Intelligent-Tiering", "Standard"]
+ParameterTypeType = Literal["SecureString", "String", "StringList"]
+ParametersFilterKeyType = Literal["KeyId", "Name", "Type"]
+PatchActionType = Literal["ALLOW_AS_DEPENDENCY", "BLOCK"]
+PatchComplianceDataStateType = Literal[
     "FAILED",
     "INSTALLED",
     "INSTALLED_OTHER",
@@ -423,11 +427,13 @@ PatchComplianceDataState = Literal[
     "MISSING",
     "NOT_APPLICABLE",
 ]
-PatchComplianceLevel = Literal["CRITICAL", "HIGH", "INFORMATIONAL", "LOW", "MEDIUM", "UNSPECIFIED"]
-PatchDeploymentStatus = Literal[
+PatchComplianceLevelType = Literal[
+    "CRITICAL", "HIGH", "INFORMATIONAL", "LOW", "MEDIUM", "UNSPECIFIED"
+]
+PatchDeploymentStatusType = Literal[
     "APPROVED", "EXPLICIT_APPROVED", "EXPLICIT_REJECTED", "PENDING_APPROVAL"
 ]
-PatchFilterKey = Literal[
+PatchFilterKeyType = Literal[
     "ADVISORY_ID",
     "ARCH",
     "BUGZILLA_ID",
@@ -448,17 +454,16 @@ PatchFilterKey = Literal[
     "SEVERITY",
     "VERSION",
 ]
-PatchOperationType = Literal["Install", "Scan"]
-PatchProperty = Literal[
+PatchOperationTypeType = Literal["Install", "Scan"]
+PatchPropertyType = Literal[
     "CLASSIFICATION", "MSRC_SEVERITY", "PRIORITY", "PRODUCT", "PRODUCT_FAMILY", "SEVERITY"
 ]
-PatchSet = Literal["APPLICATION", "OS"]
-PingStatus = Literal["ConnectionLost", "Inactive", "Online"]
-PlatformType = Literal["Linux", "Windows"]
-RebootOption = Literal["NoReboot", "RebootIfNeeded"]
-ResourceDataSyncS3Format = Literal["JsonSerDe"]
-ResourceType = Literal["Document", "EC2Instance", "ManagedInstance"]
-ResourceTypeForTagging = Literal[
+PatchSetType = Literal["APPLICATION", "OS"]
+PingStatusType = Literal["ConnectionLost", "Inactive", "Online"]
+PlatformTypeType = Literal["Linux", "Windows"]
+RebootOptionType = Literal["NoReboot", "RebootIfNeeded"]
+ResourceDataSyncS3FormatType = Literal["JsonSerDe"]
+ResourceTypeForTaggingType = Literal[
     "Document",
     "MaintenanceWindow",
     "ManagedInstance",
@@ -467,16 +472,17 @@ ResourceTypeForTagging = Literal[
     "Parameter",
     "PatchBaseline",
 ]
-ReviewStatus = Literal["APPROVED", "NOT_REVIEWED", "PENDING", "REJECTED"]
-SessionFilterKey = Literal[
+ResourceTypeType = Literal["Document", "EC2Instance", "ManagedInstance"]
+ReviewStatusType = Literal["APPROVED", "NOT_REVIEWED", "PENDING", "REJECTED"]
+SessionFilterKeyType = Literal[
     "InvokedAfter", "InvokedBefore", "Owner", "SessionId", "Status", "Target"
 ]
-SessionState = Literal["Active", "History"]
-SessionStatus = Literal[
+SessionStateType = Literal["Active", "History"]
+SessionStatusType = Literal[
     "Connected", "Connecting", "Disconnected", "Failed", "Terminated", "Terminating"
 ]
-SignalType = Literal["Approve", "Reject", "Resume", "StartStep", "StopStep"]
-StepExecutionFilterKey = Literal[
+SignalTypeType = Literal["Approve", "Reject", "Resume", "StartStep", "StopStep"]
+StepExecutionFilterKeyType = Literal[
     "Action",
     "StartTimeAfter",
     "StartTimeBefore",
@@ -484,4 +490,4 @@ StepExecutionFilterKey = Literal[
     "StepExecutionStatus",
     "StepName",
 ]
-StopType = Literal["Cancel", "Complete"]
+StopTypeType = Literal["Cancel", "Complete"]
