@@ -1,7 +1,7 @@
 """
 Type annotations for ssm service client waiters.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html)
+[Open documentation](./waiters.md)
 
 Usage::
 
@@ -20,14 +20,14 @@ Usage::
 """
 from botocore.waiter import Waiter as Boto3Waiter
 
-from mypy_boto3_ssm.type_defs import WaiterConfigTypeDef
+from .type_defs import WaiterConfigTypeDef
 
 __all__ = ("CommandExecutedWaiter",)
 
 
 class CommandExecutedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ssm.html#SSM.Waiter.command_executed)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecutedwaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ssm.html#SSM.Waiter.command_executed)[Show boto3-stubs documentation](./waiters.md#commandexecutedwaiter)
     """
 
     def wait(
@@ -38,6 +38,6 @@ class CommandExecutedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ssm.html#SSM.Waiter.CommandExecutedWaiter)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecuted)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ssm.html#SSM.Waiter.CommandExecutedWaiter)
+        [Show boto3-stubs documentation](./waiters.md#commandexecuted)
         """
